@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -33,13 +32,11 @@
 #include <sys/time.h>
 #include <sys/types.h>
 #include <dirent.h>
-
 #include <glib.h>
 #include <gio/gio.h>
-#include <gconf/gconf-client.h>
 #include "file-utils.h"
 #include "glib-utils.h"
-#include "main.h"
+#include "fr-init.h"
 
 
 #ifndef HAVE_MKDTEMP
@@ -915,13 +912,13 @@ get_temp_work_dir (const char *parent_folder)
 	char    *template;
 	char    *result = NULL;
 
-	if (parent_folder == NULL) { 	
+	if (parent_folder == NULL) {
 		/* find the folder with more free space. */
-	
+
 		for (i = 0; try_folder[i] != NULL; i++) {
 			char    *folder;
 			guint64  size;
-	
+
 			folder = ith_temp_folder_to_try (i);
 			size = get_dest_free_space (folder);
 			if (max_size < size) {
@@ -932,13 +929,13 @@ get_temp_work_dir (const char *parent_folder)
 			else
 				g_free (folder);
 		}
-	}	
-	else 
+	}
+	else
 		best_folder = g_strdup (parent_folder);
-		
+
 	if (best_folder == NULL)
 		return NULL;
-	
+
 	template = g_strconcat (best_folder, "/.fr-XXXXXX", NULL);
 	result = mkdtemp (template);
 
@@ -954,8 +951,7 @@ get_temp_work_dir (const char *parent_folder)
 gboolean
 is_temp_work_dir (const char *dir)
 {
-	int   i;
-	char *folder;
+	int i;
 
 	if (strncmp (dir, "file://", 7) == 0)
 		dir = dir + 7;
@@ -963,16 +959,19 @@ is_temp_work_dir (const char *dir)
 		return FALSE;
 
 	for (i = 0; try_folder[i] != NULL; i++) {
+		char *folder;
 
 		folder = ith_temp_folder_to_try (i);
-		if (strncmp (dir, folder, strlen (folder)) == 0)
+		if (strncmp (dir, folder, strlen (folder)) == 0) {
 			if (strncmp (dir + strlen (folder), "/.fr-", 5) == 0) {
 				g_free (folder);
 				return TRUE;
 			}
+		}
+
+		g_free (folder);
 	}
 
-	g_free (folder);
 	return FALSE;
 }
 
@@ -1235,6 +1234,29 @@ get_home_relative_file (const char *partial_uri)
 }
 
 
+GFile *
+get_user_config_subdirectory (const char *child_name,
+			      gboolean    create_child)
+{
+	char   *full_path;
+	GFile  *file;
+	GError *error = NULL;
+
+	full_path = g_strconcat (g_get_user_config_dir (), "/", child_name, NULL);
+	file = g_file_new_for_path (full_path);
+	g_free (full_path);
+
+	if  (create_child && ! make_directory_tree (file, 0700, &error)) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
+		g_object_unref (file);
+		file = NULL;
+	}
+
+	return file;
+}
+
+
 const char *
 remove_host_from_uri (const char *uri)
 {
